{% load static %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="X-UA-Compatible" content="ie=edge" />
    <title>Production Graph</title>
    <meta name="description" content="" />
    <meta name="keywords" content="" />
    <meta name="author" content="" />

    <link rel="stylesheet" href="{% static 'css/styles.css' %}" />
  </head>

  <body class="bg-gray-100 font-serif leading-normal tracking-normal">
    <nav class="bg-gray-800">
      <div class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div class="flex items-center h-16">
          <div class="absolute right-0 mr-12">
            <button
              class="max-w-xs flex items-center text-sm rounded-full text-white focus:outline-none focus:shadow-solid"
            >
              <img
                class="h-8 w-8 rounded-full"
                src="https://www.gravatar.com/avatar?d=mp"
                alt="avatar"
              />
            </button>
          </div>
        </div>
      </div>
    </nav>
    {% block content %} {% endblock %}
  </body>
</html>
